@@ -894,9 +894,7 @@ class Connection:
         if self.ssl and self.server_capabilities & CLIENT.SSL:
             await self.write_packet(data_init)
 
-            self._sock = trio.ssl.SSLStream(
-                self._sock, self.ctx, server_hostname=self.host
-            )
+            self._sock = trio.SSLStream(self._sock, self.ctx, server_hostname=self.host)
             await self._sock.do_handshake()
             self._secure = True
 
@@ -1004,9 +1002,9 @@ class Connection:
                         % (plugin_name, type(handler)),
                     )
         if plugin_name == b"caching_sha2_password":
-            return _auth.caching_sha2_password_auth(self, auth_packet)
+            return await _auth.caching_sha2_password_auth(self, auth_packet)
         elif plugin_name == b"sha256_password":
-            return _auth.sha256_password_auth(self, auth_packet)
+            return await _auth.sha256_password_auth(self, auth_packet)
         elif plugin_name == b"mysql_native_password":
             data = _auth.scramble_native_password(self.password, auth_packet.read_all())
         elif plugin_name == b"client_ed25519":
